@@ -32,16 +32,39 @@ from .crud import *
 from .autocomplete import *
 
 
+def home(request):
+    """
+    Default home view.
+    """
+
+    return {}
+
+
+def add_routes(config):
+    config.add_route('home', '/')
+
+
 def includeme(config):
+    add_routes(config)
+
+    config.add_forbidden_view('edbob.pyramid.views.forbidden')
+
+    config.add_view(home, route_name='home',
+                    renderer='/home.mako')
+
+    config.include('tailbone.views.auth')
     config.include('tailbone.views.batches')
-    # config.include('tailbone.views.categories')
+    config.include('tailbone.views.brands')
+    config.include('tailbone.views.categories')
     config.include('tailbone.views.customergroups')
     config.include('tailbone.views.customers')
     config.include('tailbone.views.departments')
     config.include('tailbone.views.employees')
     config.include('tailbone.views.labels')
+    config.include('tailbone.views.people')
     config.include('tailbone.views.products')
     config.include('tailbone.views.roles')
     config.include('tailbone.views.stores')
     config.include('tailbone.views.subdepartments')
+    config.include('tailbone.views.users')
     config.include('tailbone.views.vendors')
